@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,7 +38,7 @@ typedef struct _GdauiCloudPriv  GdauiCloudPriv;
 /* struct for the object's data */
 struct _GdauiCloud
 {
-	GtkVBox             object;
+	GtkBox             object;
 
 	GdauiCloudPriv     *priv;
 };
@@ -45,7 +46,7 @@ struct _GdauiCloud
 /* struct for the object's class */
 struct _GdauiCloudClass
 {
-	GtkVBoxClass       parent_class;
+	GtkBoxClass       parent_class;
 	void            (* activate) (GdauiCloud *cloud, gint row);
 };
 
