@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,6 +37,7 @@
 #include "data-entries/gdaui-data-cell-renderer-textual.h"
 #include "data-entries/gdaui-data-cell-renderer-boolean.h"
 #include "data-entries/gdaui-data-cell-renderer-bin.h"
+#include "gdaui-resources.h"
 
 /* plugins list */
 
@@ -85,6 +87,35 @@ gdaui_init (void)
 	if (! gdaui_plugins_hash)
 		gdaui_plugins_hash = init_plugins_hash ();
 
+	/* initialize CSS */
+	GBytes *css_data;
+	GError *error = NULL;
+	_gdaui_register_resource ();
+	css_data = g_resources_lookup_data ("/gdaui/gdaui.css", G_RESOURCE_LOOKUP_FLAGS_NONE, &error);
+	if (css_data) {
+		GtkCssProvider *css_provider;
+		css_provider = gtk_css_provider_new ();
+		if (gtk_css_provider_load_from_data (css_provider,
+						       (gchar*) g_bytes_get_data (css_data, NULL), -1,
+						       &error))
+			gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+								   GTK_STYLE_PROVIDER (css_provider),
+								   G_MAXUINT);
+		else {
+			g_warning ("Could not parse resource CSS data: %s",
+				   error && error->message ? error->message : _("No detail"));
+			g_clear_error (&error);
+		}
+		g_object_unref (css_provider);
+		g_bytes_unref (css_data);
+	}
+	else {
+		g_warning ("Could not load resource CSS data: %s",
+			   error && error->message ? error->message : _("No detail"));
+		g_clear_error (&error);
+	}
+	_gdaui_unregister_resource ();
+
 	initialized = TRUE;
 }
 
@@ -97,7 +128,7 @@ gdaui_init (void)
  * if @plugin_name is not %NULL (if no entry of that name is found, then the default data
  * entry widget will be created).
  *
- * @plugin_name format is interpreted as two parts: &lt;plugin name&gt;:&lt;plugin options&gt;, and
+ * The @plugin_name format is interpreted as two parts: &lt;plugin name&gt;:&lt;plugin options&gt;, and
  * if the plugins has no option, then the ":&lt;plugin options&gt;" part may be omitted.
  * 
  * Returns: (transfer full): a new #GdauiDataEntry widget, _NEVER_ %NULL
@@ -461,18 +492,23 @@ init_plugins_hash (void)
 	GDir *dir;
 	GError *err = NULL;
 	gchar *plugins_dir;
+	gboolean show_status = FALSE;
 	
 	/* read the plugin directory */
 	plugins_dir = gda_gbr_get_file_path (GDA_LIB_DIR, LIBGDA_ABI_NAME, "plugins", NULL);
-	g_print ("Trying to load plugins in %s...\n", plugins_dir);
+	if (g_getenv ("GDAUI_SHOW_PLUGINS_LOADING"))
+		show_status = TRUE;
+	if (show_status)
+		g_print ("Trying to load plugins in %s...\n", plugins_dir);
 	dir = g_dir_open (plugins_dir, 0, NULL);
 	if (!dir) {
 		g_free (plugins_dir);
 		plugins_dir = g_strdup (PLUGINSDIR);
-		g_print ("Trying to load plugins in %s...\n", plugins_dir);
+		if (show_status)
+			g_print ("Trying to load plugins in %s...\n", plugins_dir);
 		dir = g_dir_open (plugins_dir, 0, NULL);
 	}
-	if (!dir)
+	if (!dir && show_status)
 		g_warning (_("Could not open plugins directory, no plugin loaded."));
 	else {
 		const gchar *name;
@@ -500,11 +536,13 @@ init_plugins_hash (void)
 
 			g_module_symbol (handle, "plugin_init", (gpointer*) &plugin_init);
 			if (plugin_init) {
-				g_print (_("Loading file %s...\n"), path);
+				if (show_status)
+					g_print (_("Loading file %s...\n"), path);
 				plugins = plugin_init (&err);
 				if (err) {
-					g_message (_("Plugins load warning: %s"),
-						   err->message ? err->message : _("No detail"));
+					if (show_status)
+						g_message (_("Plugins load warning: %s"),
+							   err->message ? err->message : _("No detail"));
 					if (err)
 						g_error_free (err);
 					err = NULL;
@@ -516,13 +554,15 @@ init_plugins_hash (void)
 					
 					plugin = (GdauiPlugin *)(list->data);
 					g_hash_table_insert (hash, plugin->plugin_name, plugin);
-					g_print ("  - loaded %s (%s):", plugin->plugin_name,
-						 plugin->plugin_descr);
-					if (plugin->entry_create_func)
-						g_print (" Entry");
-					if (plugin->cell_create_func)
-						g_print (" Cell");
-					g_print ("\n");
+					if (show_status) {
+						g_print ("  - loaded %s (%s):", plugin->plugin_name,
+							 plugin->plugin_descr);
+						if (plugin->entry_create_func)
+							g_print (" Entry");
+						if (plugin->cell_create_func)
+							g_print (" Cell");
+						g_print ("\n");
+					}
 					plugin->plugin_file = g_strdup (path);
 				}
 				g_slist_free (plugins);
