@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2005 Andrew Hill <andru@src.gnome.org>
- * Copyright (C) 2005 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
  * Copyright (C) 2007 - 2008 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2008 Johannes Schmid <johannes.schmid@openismus.com>
@@ -78,7 +78,7 @@ enum
 };
 
 static GObjectClass *parent_class = NULL;
-GdaAttributesManager *gda_column_attributes_manager;
+GdaAttributesManager *_gda_column_attributes_manager;
 
 static void
 gda_column_class_init (GdaColumnClass *klass)
@@ -89,7 +89,7 @@ gda_column_class_init (GdaColumnClass *klass)
 	
 	/* signals */
 	/**
-	 * GdaColumn::name-changed
+	 * GdaColumn::name-changed:
 	 * @column: the #GdaColumn object
 	 * @old_name: the column's previous name
 	 *
@@ -105,7 +105,7 @@ gda_column_class_init (GdaColumnClass *klass)
 			      G_TYPE_NONE,
 			      1, G_TYPE_STRING);
 	/**
-	 * GdaColumn::g-type-changed
+	 * GdaColumn::g-type-changed:
 	 * @column: the #GdaColumn object
 	 * @old_type: the column's previous type
 	 * @new_type: the column's new type
@@ -135,7 +135,7 @@ gda_column_class_init (GdaColumnClass *klass)
 	object_class->finalize = gda_column_finalize;
 
 	/* extra */
-	gda_column_attributes_manager = gda_attributes_manager_new (TRUE, NULL, NULL);
+	_gda_column_attributes_manager = gda_attributes_manager_new (TRUE, NULL, NULL);
 }
 
 static void
@@ -181,7 +181,7 @@ gda_column_get_type (void)
 	static GType type = 0;
 	
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaColumnClass),
 			(GBaseInitFunc) NULL,
@@ -194,10 +194,10 @@ gda_column_get_type (void)
 			(GInstanceInitFunc) gda_column_init,
 			0
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (PARENT_TYPE, "GdaColumn", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	
 	return type;
@@ -292,7 +292,7 @@ gda_column_copy (GdaColumn *column)
 	column_copy->priv->position = column->priv->position;
 	if (column->priv->default_value)
 		column_copy->priv->default_value = gda_value_copy (column->priv->default_value);
-	gda_attributes_manager_copy (gda_column_attributes_manager, (gpointer) column, gda_column_attributes_manager, (gpointer) column_copy);
+	gda_attributes_manager_copy (_gda_column_attributes_manager, (gpointer) column, _gda_column_attributes_manager, (gpointer) column_copy);
 
 	return column_copy; 	 
 }
@@ -589,7 +589,7 @@ const GValue *
 gda_column_get_attribute (GdaColumn *column, const gchar *attribute)
 {
 	g_return_val_if_fail (GDA_IS_COLUMN (column), NULL);
-	return gda_attributes_manager_get (gda_column_attributes_manager, column, attribute);
+	return gda_attributes_manager_get (_gda_column_attributes_manager, column, attribute);
 }
 
 /**
@@ -626,10 +626,10 @@ gda_column_set_attribute (GdaColumn *column, const gchar *attribute, const GValu
 	const GValue *cvalue;
 	g_return_if_fail (GDA_IS_COLUMN (column));
 
-	cvalue = gda_attributes_manager_get (gda_column_attributes_manager, column, attribute);
+	cvalue = gda_attributes_manager_get (_gda_column_attributes_manager, column, attribute);
 	if ((value && cvalue && !gda_value_differ (cvalue, value)) ||
 	    (!value && !cvalue))
 		return;
 
-	gda_attributes_manager_set_full (gda_column_attributes_manager, column, attribute, value, destroy);
+	gda_attributes_manager_set_full (_gda_column_attributes_manager, column, attribute, value, destroy);
 }
