@@ -3,9 +3,10 @@
  * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
  * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
  * Copyright (C) 2005 Dan Winship <danw@src.gnome.org>
- * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -63,9 +64,18 @@ typedef enum {
 	GDA_DATA_MODEL_HINT_REFRESH
 } GdaDataModelHint;
 
+/**
+ * GdaDataModelIOFormat:
+ * @GDA_DATA_MODEL_IO_DATA_ARRAY_XML: data is exported as an XML structure
+ * @GDA_DATA_MODEL_IO_TEXT_SEPARATED: data is exported as CSV
+ * @GDA_DATA_MODEL_IO_TEXT_TABLE: data is exported as a human readable table
+ *
+ * Format to use when exporting a data model, see gda_data_model_export_to_string() and gda_data_model_export_to_file()
+ */
 typedef enum {
 	GDA_DATA_MODEL_IO_DATA_ARRAY_XML,
-	GDA_DATA_MODEL_IO_TEXT_SEPARATED
+	GDA_DATA_MODEL_IO_TEXT_SEPARATED,
+	GDA_DATA_MODEL_IO_TEXT_TABLE
 } GdaDataModelIOFormat;
 
 typedef enum {
@@ -139,6 +149,10 @@ struct _GdaDataModelIface {
  * column have the same type, and all the data in each row have the same semantic meaning. The #GdaDataModel is
  * actually an interface implemented by other objects to support various kinds of data storage and operations.
  *
+ * When a SELECT statement is executed using an opened #GdaConnection, the returned value (if no error occurred)
+ * is a #GdaDataSelect object which implements the #GdaDataModel interface. Please see the #GdaDataSelect's
+ * documentation for more information.
+ *
  * Depending on the real implementation, the contents of data models may be modified by the user using functions
  * provided by the model. The actual operations a data model permits can be known using the 
  * gda_data_model_get_access_flags() method.
@@ -149,8 +163,9 @@ struct _GdaDataModelIface {
  * <itemizedlist>
  *   <listitem><para>Random access to a data model's contents is done using gda_data_model_get_value_at(), or using
  *       one or more #GdaDataModelIter object(s);</para></listitem>
- *   <listitem><para>Cursor access to a data model's contents is done using a #GdaDataModelIter object (only one can be created),
- *       it is <emphasis>not possible</emphasis> to use gda_data_model_get_value_at() in this mode.</para></listitem>
+ *   <listitem><para>Cursor access to a data model's contents is done using a #GdaDataModelIter object. If this mode is
+ *       the only supported, then only one #GdaDataModelIter object can be created and
+ *       it is <emphasis>not possible</emphasis> to use gda_data_model_get_value_at() in this case.</para></listitem>
  * </itemizedlist>
  *
  * Random access data models are easier to use since picking a value is very simple using the gda_data_model_get_value_at(),
