@@ -8,7 +8,7 @@
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
+ * Copyright (C) 2011 - 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -83,7 +83,7 @@ enum
 	PROP_SPEC_FILE
 };
 
-extern xmlDtdPtr gda_server_op_dtd;
+extern xmlDtdPtr _gda_server_op_dtd;
 static GObjectClass *parent_class = NULL;
 
 typedef struct _Node {
@@ -146,7 +146,7 @@ gda_server_operation_class_init (GdaServerOperationClass *klass)
 
 	/* signals */
 	/**
-	 * GdaServerOperation::sequence-item-added
+	 * GdaServerOperation::sequence-item-added:
 	 * @op: the #GdaServerOperation
 	 * @seq_path: the path to the new sequence item
 	 * @item_index: the index (starting from 0) of the new sequence item in the sequence
@@ -162,7 +162,7 @@ gda_server_operation_class_init (GdaServerOperationClass *klass)
 			      _gda_marshal_VOID__STRING_INT, G_TYPE_NONE,
 			      2, G_TYPE_STRING, G_TYPE_INT);
 	/**
-	 * GdaServerOperation::sequence-item-remove
+	 * GdaServerOperation::sequence-item-remove:
 	 * @op: the #GdaServerOperation
 	 * @seq_path: the path to the sequence item to be removed
 	 * @item_index: the index (starting from 0) of the sequence item in the sequence
@@ -279,7 +279,7 @@ gda_server_operation_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 
 		static const GTypeInfo info = {
 			sizeof (GdaServerOperationClass),
@@ -294,10 +294,10 @@ gda_server_operation_get_type (void)
 			0
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (!type)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaServerOperation", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -684,15 +684,15 @@ use_xml_spec (GdaServerOperation *op, xmlDocPtr doc, const gchar *xmlfile)
 	xmlDoValidityCheckingDefaultValue = 1;
 	
 	/* replace the DTD with ours */
-	if (gda_server_op_dtd) {
+	if (_gda_server_op_dtd) {
 		old_dtd = doc->intSubset;
-		doc->intSubset = gda_server_op_dtd;
+		doc->intSubset = _gda_server_op_dtd;
 	}
 #ifndef G_OS_WIN32
 	if (doc->intSubset && !xmlValidateDocument (validc, doc)) {
 		gchar *str;
 		
-		if (gda_server_op_dtd)
+		if (_gda_server_op_dtd)
 			doc->intSubset = old_dtd;
 		xmlFreeDoc (doc);
 		g_free (validc);
@@ -723,7 +723,7 @@ use_xml_spec (GdaServerOperation *op, xmlDocPtr doc, const gchar *xmlfile)
 	
 	xmlDoValidityCheckingDefaultValue = xmlcheck;
 	g_free (validc);
-	if (gda_server_op_dtd)
+	if (_gda_server_op_dtd)
 		doc->intSubset = old_dtd;
 	op->priv->xml_spec_doc = doc;
 
@@ -1998,7 +1998,7 @@ gda_server_operation_del_item_from_sequence (GdaServerOperation *op, const gchar
  *
  * Get the value for the node at the @path path
  *
- * Returns: (transfer none): a constant #GValue if a value has been defined, or %NULL if the value is undefined or if the @path is not defined or @path does not hold any value.
+ * Returns: (transfer none) (allow-none): a constant #GValue if a value has been defined, or %NULL if the value is undefined or if the @path is not defined or @path does not hold any value.
  *
  * Since: 4.2.6
  *
@@ -2718,6 +2718,7 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 			/* First argument for Column's name */
 			if(!gda_server_operation_set_value_at (op, arg, error, "/FIELDS_A/@COLUMN_NAME/%d", i)){
 				g_object_unref (op);
+				va_end (args);
 				return NULL;
 			}
 
@@ -2727,12 +2728,14 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 				g_set_error (error, GDA_SERVER_OPERATION_ERROR, GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
 					     "%s", _("Invalid type"));
 				g_object_unref (op);
+				va_end (args);
 				return NULL;
 			}
 			dbms_type = (gchar *) gda_server_provider_get_default_dbms_type (server,
 											 cnc, type);
 			if (!gda_server_operation_set_value_at (op, dbms_type, error, "/FIELDS_A/@COLUMN_TYPE/%d", i)){
 				g_object_unref (op);
+				va_end (args);
 				return NULL;
 			}
 
@@ -2741,21 +2744,25 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 			if (flag & GDA_SERVER_OPERATION_CREATE_TABLE_PKEY_FLAG)
 				if(!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_PKEY/%d", i)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 			if (flag & GDA_SERVER_OPERATION_CREATE_TABLE_NOT_NULL_FLAG)
 				if(!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_NNUL/%d", i)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 			if (flag & GDA_SERVER_OPERATION_CREATE_TABLE_AUTOINC_FLAG)
 				if (!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_AUTOINC/%d", i)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 			if (flag & GDA_SERVER_OPERATION_CREATE_TABLE_UNIQUE_FLAG)
 				if(!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_UNIQUE/%d", i)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 			if (flag & GDA_SERVER_OPERATION_CREATE_TABLE_FKEY_FLAG) {
@@ -2771,6 +2778,7 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 				if (!gda_server_operation_set_value_at (op, fkey_table, error,
 								   "/FKEY_S/%d/FKEY_REF_TABLE", refs)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 
@@ -2783,6 +2791,7 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 					if(!gda_server_operation_set_value_at (op, field, error,
 									   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_FIELD/%d", refs, j)){
 						g_object_unref (op);
+						va_end (args);
 						return NULL;
 					}
 
@@ -2790,6 +2799,7 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 					if(!gda_server_operation_set_value_at (op, rfield, error,
 									   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_REF_PK_FIELD/%d", refs, j)){
 						g_object_unref (op);
+						va_end (args);
 						return NULL;
 					}
 				}
@@ -2798,12 +2808,14 @@ gda_server_operation_prepare_create_table (GdaConnection *cnc, const gchar *tabl
 				if (!gda_server_operation_set_value_at (op, fkey_ondelete, error,
 								   "/FKEY_S/%d/FKEY_ONDELETE", refs)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 				fkey_onupdate = va_arg (args, gchar*);
 				if(!gda_server_operation_set_value_at (op, fkey_onupdate, error,
 								   "/FKEY_S/%d/FKEY_ONUPDATE", refs)){
 					g_object_unref (op);
+					va_end (args);
 					return NULL;
 				}
 			}
