@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -175,7 +175,7 @@ gda_tree_mgr_columns_get_type (void)
         static GType type = 0;
 
         if (G_UNLIKELY (type == 0)) {
-                static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+                static GMutex registering;
                 static const GTypeInfo info = {
                         sizeof (GdaTreeMgrColumnsClass),
                         (GBaseInitFunc) NULL,
@@ -189,10 +189,10 @@ gda_tree_mgr_columns_get_type (void)
 			0
                 };
 
-                g_static_mutex_lock (&registering);
+                g_mutex_lock (&registering);
                 if (type == 0)
                         type = g_type_register_static (GDA_TYPE_TREE_MANAGER, "GdaTreeMgrColumns", &info, 0);
-                g_static_mutex_unlock (&registering);
+                g_mutex_unlock (&registering);
         }
         return type;
 }
@@ -299,7 +299,7 @@ gda_tree_mgr_columns_update_children (GdaTreeManager *manager, GdaTreeNode *node
 
 	if (!mgr->priv->cnc && !mgr->priv->mstore) {
 		g_set_error (error, GDA_TREE_MANAGER_ERROR, GDA_TREE_MANAGER_UNKNOWN_ERROR,
-			     _("No connection and no GdaMetaStore specified"));
+			     "%s", _("No connection and no GdaMetaStore specified"));
 		if (out_error)
 			*out_error = TRUE;
 		return NULL;
@@ -385,7 +385,7 @@ gda_tree_mgr_columns_update_children (GdaTreeManager *manager, GdaTreeNode *node
 
 	if (!schema_specified) {
 		g_set_error (error, GDA_TREE_MANAGER_ERROR, GDA_TREE_MANAGER_UNKNOWN_ERROR,
-			     _("No schema specified"));
+			     "%s", _("No schema specified"));
 		if (out_error)
 			*out_error = TRUE;
 		return NULL;
@@ -393,7 +393,7 @@ gda_tree_mgr_columns_update_children (GdaTreeManager *manager, GdaTreeNode *node
 
 	if (!table_specified) {
 		g_set_error (error, GDA_TREE_MANAGER_ERROR, GDA_TREE_MANAGER_UNKNOWN_ERROR,
-			     _("No table specified"));
+			     "%s", _("No table specified"));
 		if (out_error)
 			*out_error = TRUE;
 		return NULL;
@@ -422,7 +422,7 @@ gda_tree_mgr_columns_update_children (GdaTreeManager *manager, GdaTreeNode *node
 			if (out_error)
 				*out_error = TRUE;
 			g_set_error (error, GDA_TREE_MANAGER_ERROR, GDA_TREE_MANAGER_UNKNOWN_ERROR,
-				     _("Unable to get column name"));
+				     "%s", _("Unable to get column name"));
 			return NULL;
 		}
 
