@@ -120,7 +120,7 @@ gda_tree_mgr_ldap_dispose (GObject *object)
 }
 
 /**
- * gda_tree_mgr_select_get_type:
+ * gda_tree_mgr_ldap_get_type:
  *
  * Returns: the GType
  *
@@ -132,7 +132,7 @@ gda_tree_mgr_ldap_get_type (void)
         static GType type = 0;
 
         if (G_UNLIKELY (type == 0)) {
-                static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+                static GMutex registering;
                 static const GTypeInfo info = {
                         sizeof (GdaTreeMgrLdapClass),
                         (GBaseInitFunc) NULL,
@@ -146,10 +146,10 @@ gda_tree_mgr_ldap_get_type (void)
 			0
                 };
 
-                g_static_mutex_lock (&registering);
+                g_mutex_lock (&registering);
                 if (type == 0)
                         type = g_type_register_static (GDA_TYPE_TREE_MANAGER, "GdaTreeMgrLdap", &info, 0);
-                g_static_mutex_unlock (&registering);
+                g_mutex_unlock (&registering);
         }
         return type;
 }
