@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2006 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2006 - 2013 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
@@ -26,8 +26,6 @@
 #include <locale.h>
 #include <glib/gi18n-lib.h>
 
-extern gchar *gda_numeric_locale;
-
 static void gda_handler_numerical_class_init (GdaHandlerNumericalClass * class);
 static void gda_handler_numerical_init (GdaHandlerNumerical * wid);
 static void gda_handler_numerical_dispose (GObject   * object);
@@ -48,7 +46,6 @@ static gboolean     gda_handler_numerical_accepts_g_type       (GdaDataHandler *
 static const gchar *gda_handler_numerical_get_descr              (GdaDataHandler *dh);
 
 struct  _GdaHandlerNumericalPriv {
-	gchar          *detailed_descr;
 	guint           nb_g_types;
 	GType          *valid_g_types;
 };
@@ -62,7 +59,7 @@ gda_handler_numerical_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaHandlerNumericalClass),
 			(GBaseInitFunc) NULL,
@@ -73,7 +70,7 @@ gda_handler_numerical_get_type (void)
 			sizeof (GdaHandlerNumerical),
 			0,
 			(GInstanceInitFunc) gda_handler_numerical_init,
-			0
+			NULL
 		};
 
 		static const GInterfaceInfo data_entry_info = {
@@ -82,12 +79,12 @@ gda_handler_numerical_get_type (void)
 			NULL
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaHandlerNumerical", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_HANDLER, &data_entry_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -120,7 +117,6 @@ gda_handler_numerical_init (GdaHandlerNumerical * hdl)
 {
 	/* Private structure */
 	hdl->priv = g_new0 (GdaHandlerNumericalPriv, 1);
-	hdl->priv->detailed_descr = "";
 	hdl->priv->nb_g_types = 13;
 	hdl->priv->valid_g_types = g_new0 (GType, hdl->priv->nb_g_types);
 	hdl->priv->valid_g_types[0] = G_TYPE_INT64;
@@ -183,63 +179,42 @@ gda_handler_numerical_new (void)
 
 /* Interface implementation */
 static gchar *
-gda_handler_numerical_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
+gda_handler_numerical_get_sql_from_value (G_GNUC_UNUSED GdaDataHandler *iface, const GValue *value)
 {
-	gchar *str, *retval;
-	GdaHandlerNumerical *hdl;
+	g_assert (value);
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_NUMERICAL (iface), NULL);
-	hdl = GDA_HANDLER_NUMERICAL (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	gchar *retval;
+	retval = gda_value_stringify ((GValue *) value);
 
-	setlocale (LC_NUMERIC, "C");
-	str = gda_value_stringify ((GValue *) value);
-	setlocale (LC_NUMERIC, gda_numeric_locale);
-	if (str)
-		retval = str;
-	else
+	if (!retval)
 		retval = g_strdup ("0");
 
 	return retval;
 }
 
 static gchar *
-gda_handler_numerical_get_str_from_value (GdaDataHandler *iface, const GValue *value)
+gda_handler_numerical_get_str_from_value (G_GNUC_UNUSED GdaDataHandler *iface, const GValue *value)
 {
-	GdaHandlerNumerical *hdl;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_NUMERICAL (iface), NULL);
-	hdl = GDA_HANDLER_NUMERICAL (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
-
+	g_assert (value);
 	return gda_value_stringify ((GValue *) value);
 }
 
+/*
+ * if @c_locale is %TRUE, then @str is expected to be in the "C" locale, and if it is %FALSE,
+ * then @str is expected to be in the current (user defined) locale
+ */
 static GValue *
-gda_handler_numerical_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GType type)
+_gda_handler_numerical_get_value_from_str_locale (const gchar *str, GType type, gboolean c_locale)
 {
-	GValue *value;
-
-	setlocale (LC_NUMERIC, "C");
-	value = gda_handler_numerical_get_value_from_str (iface, sql, type);
-	setlocale (LC_NUMERIC, gda_numeric_locale);
-
-	return value;
-}
-
-static GValue *
-gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *str, GType type)
-{
-	GdaHandlerNumerical *hdl;
+	g_assert (str);
 	GValue *value = NULL;
 	long long int llint;
 	char *endptr = NULL;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_NUMERICAL (iface), NULL);
-	hdl = GDA_HANDLER_NUMERICAL (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
-
-	llint = strtoll (str, &endptr, 10);
+	if (c_locale)
+		llint = g_ascii_strtoull (str, &endptr, 10);
+	else
+		llint = strtoll (str, &endptr, 10);
 
 	if (type == G_TYPE_INT64) {
 		if (!*endptr && (llint >= G_MININT64) && (llint <= G_MAXINT64)) {
@@ -249,12 +224,26 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 	}
 	else if (type == G_TYPE_DOUBLE) {
 		gdouble dble;
-		dble = g_strtod (str, &endptr);
+		if (c_locale)
+			dble = g_ascii_strtod (str, &endptr);
+		else
+			dble = g_strtod (str, &endptr);
 		if (!*endptr) {
 			value = g_value_init (g_new0 (GValue, 1), G_TYPE_DOUBLE);
 			g_value_set_double (value, dble);
 		}
 	}
+	else if (type == G_TYPE_FLOAT) {
+		gfloat flt;
+		if (c_locale)
+			flt = g_ascii_strtod (str, &endptr);
+		else
+			flt = strtof (str, &endptr);
+		if (!*endptr) {
+			value = g_value_init (g_new0 (GValue, 1), G_TYPE_FLOAT);
+			g_value_set_float (value, flt);
+		}
+	}
 	else if (type == G_TYPE_INT) {
 		if (!*endptr && (llint >= G_MININT) && (llint <= G_MAXINT)) {
 			value = g_value_init (g_new0 (GValue, 1), G_TYPE_INT);
@@ -291,20 +280,20 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 			p++;
 		}
 		if (ok) {
-			gda_numeric_set_from_string (numeric, (gchar*) str);
-			value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_NUMERIC);
-			gda_value_set_numeric (value, numeric);
+			gdouble d;
+			char *end = NULL;
+			if (c_locale)
+				d = g_ascii_strtod (str, &end);
+			else
+				d = strtod (str, &end);
+			if (! *end) {
+				value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_NUMERIC);
+				gda_numeric_set_double (numeric, d);
+				gda_value_set_numeric (value, numeric);
+			}
 		}
 		gda_numeric_free (numeric);
 	}
-	else if (type == G_TYPE_FLOAT) {
-		gfloat flt;
-		flt = strtof (str, &endptr);
-		if (!*endptr) {
-			value = g_value_init (g_new0 (GValue, 1), G_TYPE_FLOAT);
-			g_value_set_float (value, flt);
-		}
-	}
 	else if (type == GDA_TYPE_SHORT) {
 		if (!*endptr && (llint >= G_MINSHORT) && (llint <= G_MAXSHORT)) {
 			value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_SHORT);
@@ -314,11 +303,7 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 	else if (type == G_TYPE_CHAR) {
 		if (!*endptr && (llint >= G_MININT8) && (llint <= G_MAXINT8)) {
 			value = g_value_init (g_new0 (GValue, 1), G_TYPE_CHAR);
-#if GLIB_CHECK_VERSION(2,31,7)
 			g_value_set_schar (value, (gchar) llint);
-#else
-			g_value_set_char (value, (gint8) llint);
-#endif
 		}
 	}
 	else if (type == G_TYPE_UINT64) {
@@ -379,18 +364,24 @@ gda_handler_numerical_get_value_from_str (GdaDataHandler *iface, const gchar *st
 	return value;
 }
 
+static GValue *
+gda_handler_numerical_get_value_from_sql (G_GNUC_UNUSED GdaDataHandler *iface, const gchar *sql, GType type)
+{
+	return _gda_handler_numerical_get_value_from_str_locale (sql, type, TRUE);
+}
 
 static GValue *
-gda_handler_numerical_get_sane_init_value (GdaDataHandler *iface, GType type)
+gda_handler_numerical_get_value_from_str (G_GNUC_UNUSED GdaDataHandler *iface, const gchar *str, GType type)
+{
+	return _gda_handler_numerical_get_value_from_str_locale (str, type, FALSE);
+}
+
+static GValue *
+gda_handler_numerical_get_sane_init_value (G_GNUC_UNUSED GdaDataHandler *iface, GType type)
 {
-	GdaHandlerNumerical *hdl;
 	GValue *value;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_NUMERICAL (iface), NULL);
-	hdl = GDA_HANDLER_NUMERICAL (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
-
 	value = gda_handler_numerical_get_value_from_sql (iface, "", type);
+
 	return value;
 }
 
@@ -399,29 +390,20 @@ gda_handler_numerical_accepts_g_type (GdaDataHandler *iface, GType type)
 {
 	GdaHandlerNumerical *hdl;
 	guint i = 0;
-	gboolean found = FALSE;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_NUMERICAL (iface), FALSE);
-	hdl = GDA_HANDLER_NUMERICAL (iface);
-	g_return_val_if_fail (hdl->priv, 0);
-
-	while (!found && (i < hdl->priv->nb_g_types)) {
+	g_assert (iface);
+	hdl = (GdaHandlerNumerical*) (iface);
+	for (i = 0; i < hdl->priv->nb_g_types; i++) {
 		if (hdl->priv->valid_g_types [i] == type)
-			found = TRUE;
-		i++;
+			return TRUE;
 	}
 
-	return found;
+	return FALSE;
 }
 
 static const gchar *
 gda_handler_numerical_get_descr (GdaDataHandler *iface)
 {
-	GdaHandlerNumerical *hdl;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_NUMERICAL (iface), NULL);
-	hdl = GDA_HANDLER_NUMERICAL (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
-
-	return g_object_get_data (G_OBJECT (hdl), "descr");
+	g_return_val_if_fail (GDA_IS_HANDLER_NUMERICAL (iface), NULL);
+	return g_object_get_data (G_OBJECT (iface), "descr");
 }
