@@ -1,9 +1,10 @@
 /*
- * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,9 +23,11 @@
  */
 
 #include "gda-handler-time.h"
+#include <gda-util.h>
 #include <string.h>
 #include <ctype.h>
 #include <glib/gi18n-lib.h>
+#include <libgda/gda-debug-macros.h>
 
 static void gda_handler_time_class_init (GdaHandlerTimeClass *class);
 static void gda_handler_time_init (GdaHandlerTime *hdl);
@@ -69,7 +72,6 @@ typedef struct _LocaleSetting {
 static gchar *render_date_locale (const GDate *date, LocaleSetting *locale);
 
 struct  _GdaHandlerTimePriv {
-	gchar          *detailed_descr;
 	guint           nb_g_types;
 	GType          *valid_g_types;
 
@@ -87,7 +89,7 @@ gda_handler_time_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaHandlerTimeClass),
 			(GBaseInitFunc) NULL,
@@ -98,7 +100,7 @@ gda_handler_time_get_type (void)
 			sizeof (GdaHandlerTime),
 			0,
 			(GInstanceInitFunc) gda_handler_time_init,
-			0
+			NULL
 		};		
 
 		static const GInterfaceInfo data_entry_info = {
@@ -107,12 +109,12 @@ gda_handler_time_get_type (void)
 			NULL
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaHandlerTime", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_HANDLER, &data_entry_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -145,12 +147,12 @@ gda_handler_time_init (GdaHandlerTime *hdl)
 {
 	/* Private structure */
 	hdl->priv = g_new0 (GdaHandlerTimePriv, 1);
-	hdl->priv->detailed_descr = _("Time and Date handler");
-	hdl->priv->nb_g_types = 3;
+	hdl->priv->nb_g_types = 4;
 	hdl->priv->valid_g_types = g_new0 (GType, 7);
 	hdl->priv->valid_g_types[0] = G_TYPE_DATE;
 	hdl->priv->valid_g_types[1] = GDA_TYPE_TIME;
 	hdl->priv->valid_g_types[2] = GDA_TYPE_TIMESTAMP;
+	hdl->priv->valid_g_types[3] = G_TYPE_DATE_TIME;
 
 	/* taking into accout the locale */
 	hdl->priv->sql_locale = g_new0 (LocaleSetting, 1);
@@ -429,7 +431,7 @@ handler_compute_locale (GdaHandlerTime *hdl)
  * @value: a #GValue value
  *
  * Returns: a new string representing @value without taking the current
- * locale into account
+ * locale into account (i.e. in the "C" locale)
  */
 gchar *
 gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *dh, const GValue *value)
@@ -438,7 +440,6 @@ gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *dh, const GValue
 	GType type;
 
 	g_return_val_if_fail (GDA_IS_HANDLER_TIME (dh), NULL);
-	g_return_val_if_fail (dh->priv, NULL);
 	type = G_VALUE_TYPE (value);
 
 	if (type == G_TYPE_DATE) {
@@ -453,12 +454,19 @@ gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *dh, const GValue
 	}
 	else if (type == GDA_TYPE_TIME) {
 		const GdaTime *tim;
-		
+		GString *string;
+		string = g_string_new ("");
+		g_string_append_c (string, '\'');
 		tim = gda_value_get_time ((GValue *) value);
-		retval = g_strdup_printf ("'%02d:%02d:%02d'",
-					  tim->hour,
-					  tim->minute,
-					  tim->second);
+		g_string_append_printf (string, "%02d:%02d:%02d",
+					tim->hour,
+					tim->minute,
+					tim->second);
+		if (tim->timezone != GDA_TIMEZONE_INVALID)
+			g_string_append_printf (string, "%+02d",
+						(int) tim->timezone / 3600);
+		g_string_append_c (string, '\'');
+		retval = g_string_free (string, FALSE);
 	}
 	else if (type == GDA_TYPE_TIMESTAMP) {
 		const GdaTimestamp *gdats;
@@ -480,7 +488,7 @@ gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *dh, const GValue
 				g_string_append_printf (string, ".%lu", gdats->fraction);
 			
 			if (gdats->timezone != GDA_TIMEZONE_INVALID)
-				g_string_append_printf (string, "%+02d", 
+				g_string_append_printf (string, "%+02d",
 							(int) gdats->timezone / 3600);
 			
 			retval = g_strdup_printf ("%s %s", str, string->str);
@@ -490,6 +498,47 @@ gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *dh, const GValue
 		else
 			retval = g_strdup ("NULL");	
 	}
+	else if (type == G_TYPE_DATE_TIME) {
+		GDateTime *ts;
+		GDate *vdate;
+
+		ts = g_value_get_boxed ((GValue *) value);
+		if (ts) {
+			gint y, m, d;
+			g_date_time_get_ymd (ts, &y, &m, &d);
+			vdate = g_date_new_dmy (d, m, y);
+			str = render_date_locale (vdate, dh->priv->sql_locale);
+			g_date_free (vdate);
+
+			if (str) {
+				GString *string;
+				string = g_string_new ("");
+				g_string_append_printf (string, "%02u:%02u:%02u",
+							g_date_time_get_hour (ts),
+							g_date_time_get_minute (ts),
+							g_date_time_get_second (ts));
+				if (g_date_time_get_microsecond (ts) != 0)
+					g_string_append_printf (string, ".%d", g_date_time_get_microsecond (ts));
+
+				GTimeSpan span;
+				span = g_date_time_get_utc_offset (ts);
+				if (span > 0)
+					g_string_append_printf (string, "+%02d",
+								(int) (span / G_TIME_SPAN_HOUR));
+				else
+					g_string_append_printf (string, "-%02d",
+								(int) (-span / G_TIME_SPAN_HOUR));
+
+				retval = g_strdup_printf ("%s %s", str, string->str);
+				g_free (str);
+				g_string_free (string, TRUE);
+			}
+			else
+				retval = g_strdup ("NULL");
+		}
+		else
+			retval = g_strdup ("NULL");
+	}
 	else
 		g_assert_not_reached ();
 
@@ -502,7 +551,7 @@ gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *dh, const GValue
  * @type: the type of data being handled
  *
  * Get a string representing the locale-dependent way to enter a date/time/datetime, using
- * a syntax suitable for the #GnomeDbFormatEntry widget
+ * a syntax suitable for the #GdauiFormatEntry widget
  *
  * Returns: a new string
  */
@@ -514,10 +563,9 @@ gda_handler_time_get_format (GdaHandlerTime *dh, GType type)
 	gint i;
 
 	g_return_val_if_fail (GDA_IS_HANDLER_TIME (dh), NULL);
-	g_return_val_if_fail (dh->priv, NULL);
 
 	string = g_string_new ("");
-	if ((type == G_TYPE_DATE) || (type == GDA_TYPE_TIMESTAMP)) {
+	if ((type == G_TYPE_DATE) || (type == GDA_TYPE_TIMESTAMP) || (type == G_TYPE_DATE_TIME)) {
 		for (i=0; i<3; i++) {
 			if (i > 0)
 				g_string_append_c (string, dh->priv->str_locale->separator);
@@ -541,7 +589,7 @@ gda_handler_time_get_format (GdaHandlerTime *dh, GType type)
 	if (type == GDA_TYPE_TIMESTAMP)
 		g_string_append_c (string, ' ');
 
-	if ((type == GDA_TYPE_TIME) || (type == GDA_TYPE_TIMESTAMP)) 
+	if ((type == GDA_TYPE_TIME) || (type == GDA_TYPE_TIMESTAMP) || (type == G_TYPE_DATE_TIME))
 		g_string_append (string, "00:00:00");
 
 	str = string->str;
@@ -557,13 +605,14 @@ gda_handler_time_get_format (GdaHandlerTime *dh, GType type)
 static gchar *
 gda_handler_time_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 {
+	g_assert (value);
+
 	gchar *retval = NULL, *str;
 	GdaHandlerTime *hdl;
 	GType type;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
+	hdl = (GdaHandlerTime*) (iface);
 	type = G_VALUE_TYPE (value);
 
 	if (type == G_TYPE_DATE) {
@@ -580,12 +629,19 @@ gda_handler_time_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 	}
 	else if (type == GDA_TYPE_TIME) {
 		const GdaTime *tim;
-
+		GString *string;
+		string = g_string_new ("");
 		tim = gda_value_get_time ((GValue *) value);
-		retval = g_strdup_printf ("'%02d:%02d:%02d'",
-					  tim->hour,
-					  tim->minute,
-					  tim->second);
+		g_string_append_c (string, '\'');
+		g_string_append_printf (string, "%02d:%02d:%02d",
+					tim->hour,
+					tim->minute,
+					tim->second);
+		if (tim->timezone != GDA_TIMEZONE_INVALID)
+			g_string_append_printf (string, "%+02d",
+						(int) tim->timezone / 3600);
+		g_string_append_c (string, '\'');
+		retval = g_string_free (string, FALSE);
 	}
 	else if (type == GDA_TYPE_TIMESTAMP) {
 		const GdaTimestamp *gdats;
@@ -607,7 +663,7 @@ gda_handler_time_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 				g_string_append_printf (string, ".%lu", gdats->fraction);
 			
 			if (gdats->timezone != GDA_TIMEZONE_INVALID)
-				g_string_append_printf (string, "%+02d", 
+				g_string_append_printf (string, "%+02d",
 							(int) gdats->timezone / 3600);
 			
 			retval = g_strdup_printf ("'%s %s'", str, string->str);
@@ -617,6 +673,47 @@ gda_handler_time_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 		else
 			retval = g_strdup ("NULL");	
 	}
+	else if (type == G_TYPE_DATE_TIME) {
+		GDateTime *ts;
+		GDate *vdate;
+
+		ts = g_value_get_boxed ((GValue *) value);
+		if (ts) {
+			gint y, m, d;
+			g_date_time_get_ymd (ts, &y, &m, &d);
+			vdate = g_date_new_dmy (d, m, y);
+			str = render_date_locale (vdate, hdl->priv->sql_locale);
+			g_date_free (vdate);
+
+			if (str) {
+				GString *string;
+				string = g_string_new ("");
+				g_string_append_printf (string, "%02u:%02u:%02u",
+							g_date_time_get_hour (ts),
+							g_date_time_get_minute (ts),
+							g_date_time_get_second (ts));
+				if (g_date_time_get_microsecond (ts) != 0)
+					g_string_append_printf (string, ".%d", g_date_time_get_microsecond (ts));
+
+				GTimeSpan span;
+				span = g_date_time_get_utc_offset (ts);
+				if (span > 0)
+					g_string_append_printf (string, "+%02d",
+								(int) (span / G_TIME_SPAN_HOUR));
+				else
+					g_string_append_printf (string, "-%02d",
+								(int) (-span / G_TIME_SPAN_HOUR));
+
+				retval = g_strdup_printf ("'%s %s'", str, string->str);
+				g_free (str);
+				g_string_free (string, TRUE);
+			}
+			else
+				retval = g_strdup ("NULL");
+		}
+		else
+			retval = g_strdup ("NULL");
+	}
 	else
 		g_assert_not_reached ();
 
@@ -627,13 +724,14 @@ static gchar *strip_quotes (const gchar *str);
 static gchar *
 gda_handler_time_get_str_from_value (GdaDataHandler *iface, const GValue *value)
 {
+	g_assert (value);
+
 	GdaHandlerTime *hdl;
 	gchar *retval = NULL, *str;
 	GType type;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
+	hdl = (GdaHandlerTime*) (iface);
 	type = G_VALUE_TYPE (value);
 
 	if (type == G_TYPE_DATE) {
@@ -669,7 +767,7 @@ gda_handler_time_get_str_from_value (GdaDataHandler *iface, const GValue *value)
 				g_string_append_printf (string, ".%lu", gdats->fraction);
 			
 			if (gdats->timezone != GDA_TIMEZONE_INVALID)
-				g_string_append_printf (string, "%+02d", 
+				g_string_append_printf (string, "%+02d",
 							(int) gdats->timezone / 3600);
 			
 			retval = g_strdup_printf ("%s %s", str, string->str);
@@ -679,6 +777,47 @@ gda_handler_time_get_str_from_value (GdaDataHandler *iface, const GValue *value)
 		else
 			retval = g_strdup ("");	
 	}
+	else if (type == G_TYPE_DATE_TIME) {
+		GDateTime *ts;
+		GDate *vdate;
+
+		ts = g_value_get_boxed ((GValue *) value);
+		if (ts) {
+			gint y, m, d;
+			g_date_time_get_ymd (ts, &y, &m, &d);
+			vdate = g_date_new_dmy (d, m, y);
+			str = render_date_locale (vdate, hdl->priv->str_locale);
+			g_date_free (vdate);
+
+			if (str) {
+				GString *string;
+				string = g_string_new ("");
+				g_string_append_printf (string, "%02u:%02u:%02u",
+							g_date_time_get_hour (ts),
+							g_date_time_get_minute (ts),
+							g_date_time_get_second (ts));
+				if (g_date_time_get_microsecond (ts) != 0)
+					g_string_append_printf (string, ".%d", g_date_time_get_microsecond (ts));
+
+				GTimeSpan span;
+				span = g_date_time_get_utc_offset (ts);
+				if (span > 0)
+					g_string_append_printf (string, "+%02d",
+								(int) (span / G_TIME_SPAN_HOUR));
+				else
+					g_string_append_printf (string, "-%02d",
+								(int) (-span / G_TIME_SPAN_HOUR));
+
+				retval = g_strdup_printf ("%s %s", str, string->str);
+				g_free (str);
+				g_string_free (string, TRUE);
+			}
+			else
+				retval = g_strdup ("NULL");
+		}
+		else
+			retval = g_strdup ("NULL");
+	}
 	else
 		g_assert_not_reached ();
        
@@ -751,14 +890,15 @@ static GValue *gda_handler_time_get_value_from_locale (GdaDataHandler *iface, co
 static GValue *
 gda_handler_time_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GType type)
 {
+	g_assert (sql);
+
 	GdaHandlerTime *hdl;
 	GValue *value = NULL;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
+	hdl = (GdaHandlerTime*) (iface);
 
-	if (sql && *sql) {
+	if (*sql) {
 		gint i = strlen (sql);
 		if ((i>=2) && (*sql=='\'') && (sql[i-1]=='\'')) {
 			gchar *str = g_strdup (sql);
@@ -774,18 +914,18 @@ gda_handler_time_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GT
 }
 
 static GValue *
-gda_handler_time_get_value_from_str (GdaDataHandler *iface, const gchar *sql, GType type)
+gda_handler_time_get_value_from_str (GdaDataHandler *iface, const gchar *str, GType type)
 {
+	g_assert (str);
 	GdaHandlerTime *hdl;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
+	hdl = (GdaHandlerTime*) (iface);
 
-	if (sql && (*sql == '\''))
+	if (*str == '\'')
 		return NULL;
 	else
-		return gda_handler_time_get_value_from_locale (iface, sql, type, hdl->priv->str_locale);
+		return gda_handler_time_get_value_from_locale (iface, str, type, hdl->priv->str_locale);
 }
 
 
@@ -795,6 +935,7 @@ static gboolean make_timestamp (GdaHandlerTime *hdl, GdaTimestamp *timestamp,
 static gboolean make_date (GdaHandlerTime *hdl, GDate *date, const gchar *value,
 			   LocaleSetting *locale, const gchar **out_endptr);
 static gboolean make_time (GdaHandlerTime *hdl, GdaTime *timegda, const gchar *value);
+static GDateTime *make_ts (GdaHandlerTime *hdl, const gchar *value, LocaleSetting *locale);
 static GValue *
 gda_handler_time_get_value_from_locale (GdaDataHandler *iface, const gchar *sql, 
 					GType type, LocaleSetting *locale)
@@ -802,38 +943,84 @@ gda_handler_time_get_value_from_locale (GdaDataHandler *iface, const gchar *sql,
 	GdaHandlerTime *hdl;
 	GValue *value = NULL;
 
-	GDate date;
-        GdaTime timegda;
-        GdaTimestamp timestamp;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
+	hdl = (GdaHandlerTime*) (iface);
 
 	if (type == G_TYPE_DATE) {
+		GDate date;
 		if (make_date (hdl, &date, sql, locale, NULL)) {
 			value = g_value_init (g_new0 (GValue, 1), G_TYPE_DATE);
 			g_value_set_boxed (value, (gconstpointer) &date);
 		}
 	}
 	else if (type == GDA_TYPE_TIME) {
+		GdaTime timegda;
 		if (make_time (hdl, &timegda, sql)) {
 			value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_TIME);
 			gda_value_set_time (value, &timegda);
 		}
 	}
 	else if (type == GDA_TYPE_TIMESTAMP) {
+		GdaTimestamp timestamp;
 		if (make_timestamp (hdl, &timestamp, sql, locale)) {
 			value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_TIMESTAMP);
 			gda_value_set_timestamp (value, &timestamp);
 		}
 	}
+	else if (type == G_TYPE_DATE_TIME) {
+		GDateTime *ts;
+		ts = make_ts (hdl, sql, locale);
+		if (ts) {
+			value = g_value_init (g_new0 (GValue, 1), G_TYPE_DATE_TIME);
+			g_value_take_boxed (value, ts);
+		}
+	}
 	else
 		g_assert_not_reached ();
 
 	return value;
 }
 
+static GDateTime *
+make_ts (GdaHandlerTime *hdl, const gchar *value, LocaleSetting *locale)
+{
+	GDateTime *ts;
+	const gchar *end_ptr;
+	GDate vdate;
+	GdaTime vtime;
+	memset (&vtime, 0, sizeof (GdaTime));
+	vtime.timezone = GDA_TIMEZONE_INVALID;
+
+	gboolean retval;
+	retval = make_date (hdl, &vdate, value, locale, &end_ptr);
+	if (retval) {
+		if (*end_ptr != ' ')
+			retval = FALSE;
+		else
+			retval = make_time (hdl, &vtime, end_ptr + 1);
+	}
+	if (!retval)
+		return NULL;
+
+	GTimeZone *tz;
+	if (vtime.timezone != GDA_TIMEZONE_INVALID) {
+		gchar *tzdef;
+		if (vtime.timezone >= 0)
+			tzdef = g_strdup_printf ("+%02d", (gint) (vtime.timezone / 3600));
+		else
+			tzdef = g_strdup_printf ("-%02d", (gint) (- vtime.timezone / 3600));
+		tz = g_time_zone_new (tzdef);
+		g_free (tzdef);
+	}
+	else
+		tz = g_time_zone_new_local ();
+	ts = g_date_time_new (tz, vdate.year, vdate.month, vdate.day,
+			      vtime.hour, vtime.minute, (gdouble) vtime.second + vtime.fraction);
+	g_time_zone_unref (tz);
+
+	return ts;
+}
+
 /* Makes a GdaTimestamp from a string like "24-12-2003 13:12:01.12+01",
  * taken from libgda/gda-value.h
  * with a modification for the date format
@@ -1022,112 +1209,22 @@ make_date (G_GNUC_UNUSED GdaHandlerTime *hdl, GDate *date, const gchar *value,
 static gboolean
 make_time (G_GNUC_UNUSED GdaHandlerTime *hdl, GdaTime *timegda, const gchar *value)
 {
-	const gchar *ptr;
-
-	memset (timegda, 0, sizeof (GdaTime));
-	timegda->timezone = GDA_TIMEZONE_INVALID;
-
-	if (!value)
-		return FALSE;
-
-	/* hour */
-	ptr = value;
-	if (!isdigit (*ptr))
-		return FALSE;
-
-	timegda->hour = *ptr - '0';
-	ptr++;
-	if (isdigit (*ptr)) {
-		timegda->hour = timegda->hour * 10 + (*ptr - '0');
-		ptr++;
-	}
-	if (timegda->hour >= 24)
-		return FALSE;
-
-	if (*ptr == ':')
-		ptr++;
-	else if (!isdigit (*ptr))
-		return FALSE;
-
-	/* minute */
-	timegda->minute = *ptr - '0';
-	ptr++;
-	if (isdigit (*ptr)) {
-		timegda->minute = timegda->minute * 10 + (*ptr - '0');
-		ptr++;
-	}
-	if (timegda->minute >= 60)
-		return FALSE;
-	if (*ptr == ':')
-		ptr++;
-	else if (!isdigit (*ptr))
-		return FALSE;
-
-	/* second */
-	timegda->second = *ptr - '0';
-	ptr++;
-	if (isdigit (*ptr)) {
-		timegda->second = timegda->second * 10 + (*ptr - '0');
-		ptr++;
-	}
-	if (timegda->second >= 60)
-		return FALSE;
-
-	/* fraction */
-	if (*ptr && (*ptr != '.') && (*ptr != '+') && (*ptr != '-'))
-		return FALSE;
-	if (*ptr == '.') {
-		ptr++;
-		if (!isdigit (*ptr))
-			return FALSE;
-		while (isdigit (*ptr)) {
-			unsigned long long lu;
-			lu = timegda->fraction * 10 + (*ptr - '0');
-			if (lu < G_MAXULONG)
-				timegda->fraction = lu;
-			else
-				return FALSE;
-			ptr++;
-		}
-	}
-	
-	/* timezone */
-	if ((*ptr == '-') || (*ptr == '+')) {
-		gint sign = (*ptr == '+') ? 1 : -1;
-		ptr++;
-		if (!isdigit (*ptr))
-			return FALSE;
-		timegda->timezone = sign * (*ptr - '0');
-		ptr++;
-		if (isdigit (*ptr)) {
-			timegda->timezone = timegda->minute * 10 + sign * (*ptr - '0');
-			ptr++;
-		}
-		if (*ptr)
-			return FALSE;
-		if ((timegda->timezone >= -24) && (timegda->timezone <= 24))
-			timegda->timezone *= 60*60;
-		else {
-			timegda->timezone = 0;
-			return FALSE;
-		}
-	}
-	return TRUE;
+	if (gda_parse_iso8601_time (timegda, value))
+		return TRUE;
+	else
+		return gda_parse_formatted_time (timegda, value, 0);
 }
 
 
 static GValue *
-gda_handler_time_get_sane_init_value (GdaDataHandler *iface, GType type)
+gda_handler_time_get_sane_init_value (G_GNUC_UNUSED GdaDataHandler *iface, GType type)
 {
-	GdaHandlerTime *hdl;
 	GValue *value = NULL;
 	
 	time_t now;
 	struct tm *stm;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
 
 	now = time (NULL);
 #ifdef HAVE_LOCALTIME_R
@@ -1172,6 +1269,15 @@ gda_handler_time_get_sane_init_value (GdaDataHandler *iface, GType type)
 		value = g_value_init (g_new0 (GValue, 1), GDA_TYPE_TIMESTAMP);
 		gda_value_set_timestamp (value, &gts);
 	}
+	else if (type == G_TYPE_DATE_TIME) {
+		GDateTime *ts;
+		GTimeZone *tz;
+		tz = g_time_zone_new_local ();
+		ts = g_date_time_new_now (tz);
+		g_time_zone_unref (tz);
+		value = g_value_init (g_new0 (GValue, 1), G_TYPE_DATE_TIME);
+		g_value_take_boxed (value, ts);
+	}
 	else
 		g_assert_not_reached ();
 
@@ -1182,30 +1288,22 @@ static gboolean
 gda_handler_time_accepts_g_type (GdaDataHandler *iface, GType type)
 {
 	GdaHandlerTime *hdl;
-	guint i = 0;
-	gboolean found = FALSE;
+	guint i;
 
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), FALSE);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, 0);
+	g_assert (iface);
+	hdl = (GdaHandlerTime*) (iface);
 
-	while (!found && (i < hdl->priv->nb_g_types)) {
+	for (i = 0; i < hdl->priv->nb_g_types; i++) {
 		if (hdl->priv->valid_g_types [i] == type)
-			found = TRUE;
-		i++;
+			return TRUE;
 	}
 
-	return found;
+	return FALSE;
 }
 
 static const gchar *
 gda_handler_time_get_descr (GdaDataHandler *iface)
 {
-	GdaHandlerTime *hdl;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), NULL);
-	hdl = GDA_HANDLER_TIME (iface);
-	g_return_val_if_fail (hdl->priv, NULL);
-
-	return g_object_get_data (G_OBJECT (hdl), "descr");
+	g_return_val_if_fail (GDA_IS_HANDLER_TIME (iface), NULL);
+	return g_object_get_data (G_OBJECT (iface), "descr");
 }
