@@ -78,24 +78,21 @@ typedef struct _GdaSqlParserIface
 } GdaSqlParserIface;
 
 /* struct for the object's class */
-/**
- * GdaSqlParserClass:
- */
 struct _GdaSqlParserClass
 {
 	GObjectClass         parent_class;
 
 	/* virtual methods and data for sub classed parsers */
-	void *(*delim_alloc) (void *(*f)(size_t s));
-	void (*delim_free) (void *d, void (*f) (void*param));
+	void *(*delim_alloc) (void *(*f) (size_t s));
+	void (*delim_free) (void  *d, void(*f) (void *d));
 	void (*delim_trace) (void *d, char *s);
 	void (*delim_parse) (void *d, int i, GValue *v, GdaSqlParserIface *iface);
 	gint *delim_tokens_trans;
 	
 	void *(*parser_alloc) (void *(*f)(size_t s));
-	void (*parser_free) (void *p, void (*f) (void *param));
+	void (*parser_free) (void *p, void(*f)(void *p));
 	void (*parser_trace) (void *p, char *s);
-	void (*parser_parse) (void *p, int i, GValue *v, GdaSqlParserIface *iface);	
+	void (*parser_parse) (void *p, int i, GValue *v, GdaSqlParserIface *iface);
 	gint *parser_tokens_trans;
 
 	/*< private >*/
