@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -248,9 +249,9 @@ typedef struct {
 	GdaSqlStatementType  type;
 	gchar               *name;
 	gpointer            (*construct) (void);
-	void                (*free) (gpointer);
-	gpointer            (*copy) (gpointer);
-	gchar              *(*serialize) (gpointer);
+	void                (*free) (gpointer stm);
+	gpointer            (*copy) (gpointer stm);
+	gchar              *(*serialize) (gpointer stm);
 
 	/* augmenting information precision using a dictionary */
 	GdaSqlForeachFunc     check_structure_func;
