@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2010 - 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -773,6 +773,10 @@ gda_sql_operation_operator_to_string (GdaSqlOperatorType op)
 		return "|";
 	case GDA_SQL_OPERATOR_TYPE_BITNOT:
 		return "~";
+	case GDA_SQL_OPERATOR_TYPE_NOTLIKE:
+		return "NOT LIKE";
+	case GDA_SQL_OPERATOR_TYPE_NOTILIKE:
+		return "NOT ILIKE";
 	default:
 		g_error ("Unhandled operator constant %d\n", op);
 		return NULL;
