@@ -50,7 +50,7 @@ _gda_sqlite_blob_op_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaSqliteBlobOpClass),
 			(GBaseInitFunc) NULL,
@@ -63,10 +63,10 @@ _gda_sqlite_blob_op_get_type (void)
 			(GInstanceInitFunc) gda_sqlite_blob_op_init,
 			0
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_BLOB_OP, CLASS_PREFIX "BlobOp", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
