@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -42,7 +42,7 @@ typedef struct {
 	BasicThreadData wdata; \
 	gpointer res; \
 	guint jid; \
-        cdata = (ThreadConnectionData*) gda_connection_internal_get_provider_data ((cnc)); \
+        cdata = (ThreadConnectionData*) gda_connection_internal_get_provider_data_error ((cnc),(error)); \
 	if (!cdata) \
 		return FALSE; \
 	wdata.prov = cdata->cnc_provider; \
@@ -80,7 +80,7 @@ typedef struct {
 	DetailedThreadData wdata; \
 	gpointer res; \
 	guint jid; \
-        cdata = (ThreadConnectionData*) gda_connection_internal_get_provider_data ((cnc)); \
+        cdata = (ThreadConnectionData*) gda_connection_internal_get_provider_data_error ((cnc),(error)); \
 	if (!cdata) \
 		return FALSE; \
 	wdata.prov = cdata->cnc_provider; \
