@@ -22,6 +22,7 @@
 #include <libgda/libgda.h>
 #include "gda-firebird.h"
 #include "gda-firebird-blob-op.h"
+#include <libgda/gda-debug-macros.h>
 
 struct _GdaFirebirdBlobOpPrivate {
 	GdaConnection *cnc;
@@ -48,7 +49,7 @@ gda_firebird_blob_op_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaFirebirdBlobOpClass),
 			(GBaseInitFunc) NULL,
@@ -60,7 +61,7 @@ gda_firebird_blob_op_get_type (void)
 			0,
 			(GInstanceInitFunc) gda_firebird_blob_op_init
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 #ifdef FIREBIRD_EMBED
 			type = g_type_register_static (GDA_TYPE_BLOB_OP, "GdaFirebirdBlobOpEmbed", &info, 0);
@@ -68,7 +69,7 @@ gda_firebird_blob_op_get_type (void)
 			type = g_type_register_static (GDA_TYPE_BLOB_OP, "GdaFirebirdBlobOp", &info, 0);
 #endif
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
