@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@
 #include <gda-value.h>
 #include <gda-server-provider.h>
 
-gboolean jni_wrapper_describe_exceptions = TRUE;
+gboolean jni_wrapper_describe_exceptions = FALSE;
 
 static jclass            SQLException__class = NULL;
 static JniWrapperMethod *get_message_method = NULL;
@@ -529,6 +529,8 @@ jni_wrapper_method_call (JNIEnv *jenv, JniWrapperMethod *method, GValue *object,
 
 				(*jenv)-> DeleteLocalRef (jenv, string);
 			}
+			else
+				gda_value_set_null (retval);
 		}
 		else {
 			JavaVM *jvm;
@@ -557,11 +559,11 @@ jni_wrapper_method_call (JNIEnv *jenv, JniWrapperMethod *method, GValue *object,
 	case 'B':
 		g_value_init (retval, G_TYPE_CHAR);
 		if (method->is_static)
-			g_value_set_char (retval,
-					  (*jenv)->CallStaticByteMethodV (jenv, method->klass, method->mid, args));
+			g_value_set_schar (retval,
+					   (*jenv)->CallStaticByteMethodV (jenv, method->klass, method->mid, args));
 		else
-			g_value_set_char (retval,
-					  (*jenv)->CallByteMethodV (jenv, jobj, method->mid, args));
+			g_value_set_schar (retval,
+					   (*jenv)->CallByteMethodV (jenv, jobj, method->mid, args));
 		break;
 	case 'C':
 		g_value_init (retval, G_TYPE_INT); // FIXME: should be an unsigned 16 bits value
@@ -743,6 +745,8 @@ jni_wrapper_field_get (JNIEnv *jenv, JniWrapperField *field, GValue *object, GEr
 
 				(*jenv)-> DeleteLocalRef (jenv, string);
 			}
+			else
+				gda_value_set_null (retval);
 		}
 		else {
 			JavaVM *jvm;
@@ -769,11 +773,11 @@ jni_wrapper_field_get (JNIEnv *jenv, JniWrapperField *field, GValue *object, GEr
 	case 'B':
 		g_value_init (retval, G_TYPE_CHAR);
 		if (field->is_static)
-			g_value_set_char (retval,
-					  (*jenv)->GetStaticByteField (jenv, field->klass, field->fid));
+			g_value_set_schar (retval,
+					   (*jenv)->GetStaticByteField (jenv, field->klass, field->fid));
 		else
-			g_value_set_char (retval,
-					  (*jenv)->GetByteField (jenv, jobj, field->fid));
+			g_value_set_schar (retval,
+					   (*jenv)->GetByteField (jenv, jobj, field->fid));
 		break;
 	case 'C':
 		g_value_init (retval, G_TYPE_INT); // FIXME: should be an unsigned 16 bits value
@@ -884,7 +888,7 @@ jni_wrapper_field_set (JNIEnv *jenv, JniWrapperField *field,
 					(*jenv)->SetObjectField (jenv, jobj, field->fid, string);
 				(*jenv)-> DeleteLocalRef (jenv, string);
 			}
-			else if (G_VALUE_TYPE (value) == 0) {
+			else if (G_VALUE_TYPE (value) == GDA_TYPE_NULL) {
 				if (field->is_static)
 					(*jenv)->SetStaticObjectField (jenv, field->klass, field->fid, NULL);
 				else
@@ -924,9 +928,9 @@ jni_wrapper_field_set (JNIEnv *jenv, JniWrapperField *field,
 		if (G_VALUE_TYPE (value) != G_TYPE_CHAR)
 			goto wrong_type;
 		if (field->is_static)
-			(*jenv)->SetStaticByteField (jenv, field->klass, field->fid, g_value_get_char (value));
+			(*jenv)->SetStaticByteField (jenv, field->klass, field->fid, g_value_get_schar (value));
 		else
-			(*jenv)->SetByteField (jenv, jobj, field->fid, g_value_get_char (value));
+			(*jenv)->SetByteField (jenv, jobj, field->fid, g_value_get_schar (value));
 		break;
 	case 'C':
 		if (G_VALUE_TYPE (value) != G_TYPE_INT)
@@ -1107,3 +1111,32 @@ gda_jni_object_free (gpointer boxed)
 	}
 	g_free (jnio);
 }
+
+jlong
+jni_cpointer_to_jlong (gconstpointer c_pointer)
+{
+	jlong retval;
+
+#if SIZEOF_INT_P == 4
+	gint32 i32;
+	i32 = (gint32) c_pointer;
+	retval = i32;
+#else
+	retval = (jlong) c_pointer;
+#endif
+	return retval;
+}
+
+gconstpointer
+jni_jlong_to_cpointer (jlong value)
+{
+	gconstpointer retval;
+#if SIZEOF_INT_P == 4
+	gint32 i32;
+	i32 = (gint32) value;
+	retval = (gconstpointer) i32;
+#else
+	retval = (gconstpointer) value;
+#endif
+	return retval;
+}
