@@ -23,6 +23,7 @@
 #include <libgda/libgda.h>
 #include "gda-mysql.h"
 #include "gda-mysql-blob-op.h"
+#include <libgda/gda-debug-macros.h>
 
 struct _GdaMysqlBlobOpPrivate {
 	GdaConnection  *cnc;
@@ -49,7 +50,7 @@ gda_mysql_blob_op_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaMysqlBlobOpClass),
 			(GBaseInitFunc) NULL,
@@ -62,10 +63,10 @@ gda_mysql_blob_op_get_type (void)
 			(GInstanceInitFunc) gda_mysql_blob_op_init,
 			NULL
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_BLOB_OP, "GdaMysqlBlobOp", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
