@@ -33,7 +33,7 @@ gda_oracle_parser_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaOracleParserClass),
 			(GBaseInitFunc) NULL,
@@ -46,10 +46,10 @@ gda_oracle_parser_get_type (void)
 			(GInstanceInitFunc) gda_oracle_parser_init
 		};
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_SQL_PARSER, "GdaOracleParser", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
