@@ -6,7 +6,7 @@
  * Copyright (C) 2003 Steve Fosdick <fozzy@src.gnome.org>
  * Copyright (C) 2004 Julio M. Merino Vidal <jmmv@menta.net>
  * Copyright (C) 2005 Magnus Bergman <magnus.bergman@observer.net>
- * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2006 - 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  *
@@ -46,6 +46,8 @@
 #include "gda-oracle-meta.h"
 #include "gda-oracle-util.h"
 #include "gda-oracle-parser.h"
+#include <libgda/gda-debug-macros.h>
+
 #define _GDA_PSTMT(x) ((GdaPStmt*)(x))
 
 /*
@@ -156,7 +158,7 @@ static void gda_oracle_free_cnc_data (OracleConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+static GMutex init_mutex;
 static GdaStatement **internal_stmt = NULL;
 
 typedef enum {
@@ -278,8 +280,8 @@ gda_oracle_provider_class_init (GdaOracleProviderClass *klass)
 	static_types[GDA_STYPE_STRING] = G_TYPE_STRING;
 	static_types[GDA_STYPE_BOOLEAN] = G_TYPE_BOOLEAN;
 	static_types[GDA_STYPE_DATE] = G_TYPE_DATE;
-	static_types[GDA_STYPE_TIME] = GDA_STYPE_TIME;
-	static_types[GDA_STYPE_TIMESTAMP] = GDA_STYPE_TIMESTAMP;
+	static_types[GDA_STYPE_TIME] = GDA_TYPE_TIME;
+	static_types[GDA_STYPE_TIMESTAMP] = GDA_TYPE_TIMESTAMP;
 	static_types[GDA_STYPE_INT64] = G_TYPE_INT64;
 	static_types[GDA_STYPE_UINT64] = G_TYPE_UINT64;
 	static_types[GDA_STYPE_UINT] = G_TYPE_UINT;
@@ -287,20 +289,20 @@ gda_oracle_provider_class_init (GdaOracleProviderClass *klass)
 	static_types[GDA_STYPE_DOUBLE] = G_TYPE_DOUBLE;
 	static_types[GDA_STYPE_LONG] = G_TYPE_LONG;
 	static_types[GDA_STYPE_ULONG] = G_TYPE_ULONG;
-	static_types[GDA_STYPE_NUMERIC] = GDA_STYPE_NUMERIC;
-	static_types[GDA_STYPE_BINARY] = GDA_STYPE_BINARY;
-	static_types[GDA_STYPE_BLOB] = GDA_STYPE_BLOB;
+	static_types[GDA_STYPE_NUMERIC] = GDA_TYPE_NUMERIC;
+	static_types[GDA_STYPE_BINARY] = GDA_TYPE_BINARY;
+	static_types[GDA_STYPE_BLOB] = GDA_TYPE_BLOB;
 	static_types[GDA_STYPE_CHAR] = G_TYPE_CHAR;
-	static_types[GDA_STYPE_SHORT] = GDA_STYPE_SHORT;
+	static_types[GDA_STYPE_SHORT] = GDA_TYPE_SHORT;
 	static_types[GDA_STYPE_GTYPE] = G_TYPE_GTYPE;
-	static_types[GDA_STYPE_GEOMETRIC_POINT] = GDA_STYPE_GEOMETRIC_POINT;
+	static_types[GDA_STYPE_GEOMETRIC_POINT] = GDA_TYPE_GEOMETRIC_POINT;
 	static_types[GDA_STYPE_NULL] = GDA_TYPE_NULL;
 }
 
 static void
 gda_oracle_provider_init (GdaOracleProvider *oracle_prv, G_GNUC_UNUSED GdaOracleProviderClass *klass)
 {
-	g_static_mutex_lock (&init_mutex);
+	g_mutex_lock (&init_mutex);
 
 	if (!internal_stmt) {
 		InternalStatementItem i;
@@ -318,7 +320,7 @@ gda_oracle_provider_init (GdaOracleProvider *oracle_prv, G_GNUC_UNUSED GdaOracle
 	/* meta data init */
 	_gda_oracle_provider_meta_init ((GdaServerProvider*) oracle_prv);
 
-	g_static_mutex_unlock (&init_mutex);
+	g_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -327,7 +329,7 @@ gda_oracle_provider_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static GTypeInfo info = {
 			sizeof (GdaOracleProviderClass),
 			(GBaseInitFunc) NULL,
@@ -339,10 +341,10 @@ gda_oracle_provider_get_type (void)
 			(GInstanceInitFunc) gda_oracle_provider_init,
 			NULL
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_SERVER_PROVIDER, "GdaOracleProvider", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
