@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@ gda_postgres_pstmt_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaPostgresPStmtClass),
 			(GBaseInitFunc) NULL,
@@ -54,10 +54,10 @@ gda_postgres_pstmt_get_type (void)
 			0
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_PSTMT, "GdaPostgresPStmt", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -78,6 +78,7 @@ gda_postgres_pstmt_init (GdaPostgresPStmt *pstmt, G_GNUC_UNUSED GdaPostgresPStmt
 	g_return_if_fail (GDA_IS_PSTMT (pstmt));
 	
 	pstmt->prep_name = NULL;
+	pstmt->date_format_change = FALSE;
 }
 
 static void
