@@ -24,6 +24,8 @@
 #include <libgda/gda-data-model-extra.h>
 #include <libgda/gda-row.h>
 #include <data-model-errors.h>
+#include <libgda/gda-debug-macros.h>
+#include "test-errors.h"
 
 #define NCOLS 4
 typedef struct {
@@ -213,7 +215,7 @@ data_model_errors_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (DataModelErrorsClass),
 			(GBaseInitFunc) NULL,
@@ -232,12 +234,12 @@ data_model_errors_get_type (void)
                         NULL
                 };
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "DataModelErrors", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -393,7 +395,7 @@ data_model_errors_set_value_at (GdaDataModel *model, gint col, gint row, const G
 	if ((col < 0) || (col > NCOLS)) {
 		gchar *tmp;
 		tmp = g_strdup_printf ("Column %d out of range (0-%d)", col, NCOLS-1);
-		g_set_error (error, 0, 0, "%s", tmp);
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", tmp);
 		g_free (tmp);
 		return FALSE;
 	}
@@ -449,7 +451,7 @@ data_model_errors_remove_row (GdaDataModel *model, gint row, GError **error)
 					       imodel->priv->rows->len - 1);
 		else
 			str = g_strdup_printf ("Row %d not found (empty data model)", row);
-		g_set_error (error, 0, 0, "%s", str);
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", str);
 		g_free (str);
                 return FALSE;
         }
