@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -88,7 +89,7 @@ auth_dialog_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (AuthDialogClass),
 			(GBaseInitFunc) NULL,
@@ -102,10 +103,10 @@ auth_dialog_get_type (void)
 			0
 		};
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GTK_TYPE_DIALOG, "AuthDialog", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
@@ -315,9 +316,9 @@ sub_thread_open_cnc (AuthData *ad, GError **error)
 	}
 #endif
 	return cnc;
-#else
+#else /* DUMMY defined */
 	sleep (5);
-	g_set_error (error, 0, 0, "%s", "Oooo");
+	g_set_error (error, GDA_TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR, "%s", "Dummy error!");
 	return NULL;
 #endif
 }
