@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
  *
@@ -31,7 +31,7 @@
 #include "../config-info.h"
 #include "browser-virtual-connection.h"
 #include <sqlite/virtual/gda-virtual-connection.h>
-
+#include <libgda/gda-debug-macros.h>
 #include "browser-connection-priv.h"
 
 #define CHECK_RESULTS_SHORT_TIMER 200
@@ -117,21 +117,11 @@ my_unlock (GMutex *mutex, gint where)
 	g_print ("tmp UNL %p (th %p)@line %d\n", mutex, g_thread_self(), where);
 }
 
-#if GLIB_CHECK_VERSION(2,31,7)
-#define MUTEX_LOCK(bcnc) g_mutex_lock (&((bcnc)->priv->mstruct_mutex))
-#define MUTEX_UNLOCK(bcnc) g_mutex_unlock (&((bcnc)->priv->mstruct_mutex))
-#else
-#define MUTEX_LOCK(bcnc) my_lock ((bcnc)->priv->p_mstruct_mutex,__LINE__)
-#define MUTEX_UNLOCK(bcnc) my_unlock ((bcnc)->priv->p_mstruct_mutex,__LINE__)
-#endif
+  #define MUTEX_LOCK(bcnc) g_mutex_lock (&((bcnc)->priv->mstruct_mutex))
+  #define MUTEX_UNLOCK(bcnc) g_mutex_unlock (&((bcnc)->priv->mstruct_mutex))
 #else /* GDA_DEBUG_MUTEX */
-#if GLIB_CHECK_VERSION(2,31,7)
-#define MUTEX_LOCK(bcnc) g_mutex_lock (&((bcnc)->priv->mstruct_mutex))
-#define MUTEX_UNLOCK(bcnc) g_mutex_unlock (&((bcnc)->priv->mstruct_mutex))
-#else
-#define MUTEX_LOCK(bcnc) g_mutex_lock ((bcnc)->priv->p_mstruct_mutex)
-#define MUTEX_UNLOCK(bcnc) g_mutex_unlock ((bcnc)->priv->p_mstruct_mutex)
-#endif
+  #define MUTEX_LOCK(bcnc) g_mutex_lock (&((bcnc)->priv->mstruct_mutex))
+  #define MUTEX_UNLOCK(bcnc) g_mutex_unlock (&((bcnc)->priv->mstruct_mutex))
 #endif /* GDA_DEBUG_MUTEX */
 
 /*
@@ -229,7 +219,7 @@ browser_connection_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (BrowserConnectionClass),
 			(GBaseInitFunc) NULL,
@@ -244,10 +234,10 @@ browser_connection_get_type (void)
 		};
 
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "BrowserConnection", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -395,11 +385,7 @@ browser_connection_init (BrowserConnection *bcnc)
 	bcnc->priv->parser = NULL;
 	bcnc->priv->variables = NULL;
 	memset (&(bcnc->priv->dsn_info), 0, sizeof (GdaDsnInfo));
-#if GLIB_CHECK_VERSION(2,31,7)
 	g_mutex_init (&bcnc->priv->mstruct_mutex);
-#else
-	bcnc->priv->p_mstruct_mutex = g_mutex_new ();
-#endif
 	bcnc->priv->p_mstruct_list = NULL;
 	bcnc->priv->c_mstruct = NULL;
 	bcnc->priv->mstruct = NULL;
@@ -478,7 +464,9 @@ wrapper_meta_struct_sync (BrowserConnection *bcnc, GError **error)
 	return GINT_TO_POINTER (retval ? 2 : 1);
 }
 
-
+/*
+ * executed in main thread
+ */
 static void
 meta_changed_cb (G_GNUC_UNUSED GdaThreadWrapper *wrapper,
 		 G_GNUC_UNUSED GdaMetaStore *store,
@@ -525,6 +513,9 @@ browser_connection_meta_data_changed (BrowserConnection *bcnc)
 	meta_changed_cb (NULL, NULL, NULL, 0, NULL, NULL, bcnc);
 }
 
+/*
+ * executed in bcnc->priv->wrapper's thread
+ */
 static gpointer
 wrapper_have_meta_store_ready (BrowserConnection *bcnc, GError **error)
 {
@@ -589,11 +580,6 @@ wrapper_have_meta_store_ready (BrowserConnection *bcnc, GError **error)
 	}
 	g_slist_free (all);
 #endif
-	bcnc->priv->meta_store_signal =
-		gda_thread_wrapper_connect_raw (bcnc->priv->wrapper, store, "meta-changed",
-						FALSE, FALSE,
-						(GdaThreadWrapperCallback) meta_changed_cb,
-						bcnc);
 	g_object_unref (store);
 	return retval ? (void*) 0x01 : NULL;
 }
@@ -685,6 +671,17 @@ browser_connection_set_property (GObject *object,
 							    lerror->message ? lerror->message : _("No detail"));
 					g_clear_error (&lerror);
 				}
+				else {
+					GdaMetaStore *store;
+					g_object_get (G_OBJECT (bcnc->priv->cnc), "meta-store", &store, NULL);
+					bcnc->priv->meta_store_signal =
+						gda_thread_wrapper_connect_raw (bcnc->priv->wrapper, store, "meta-changed",
+										FALSE, FALSE,
+										(GdaThreadWrapperCallback) meta_changed_cb,
+										bcnc);
+					g_object_unref (store);
+				}
+
 			}
                         break;
 		default:
@@ -800,12 +797,7 @@ browser_connection_dispose (GObject *object)
 			g_slist_foreach (bcnc->priv->p_mstruct_list, (GFunc) g_object_unref, NULL);
 			g_slist_free (bcnc->priv->p_mstruct_list);
 		}
-#if GLIB_CHECK_VERSION(2,31,7)
 		g_mutex_clear (&bcnc->priv->mstruct_mutex);
-#else
-		if (bcnc->priv->p_mstruct_mutex)
-			g_mutex_free (bcnc->priv->p_mstruct_mutex);
-#endif
 
 		if (bcnc->priv->cnc)
 			g_object_unref (bcnc->priv->cnc);
