@@ -60,7 +60,7 @@ data_manager_perspective_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (DataManagerPerspectiveClass),
 			(GBaseInitFunc) NULL,
@@ -80,12 +80,12 @@ data_manager_perspective_get_type (void)
                         NULL
                 };
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (GTK_TYPE_BOX, "DataManagerPerspective", &info, 0);
 			g_type_add_interface_static (type, BROWSER_PERSPECTIVE_TYPE, &perspective_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -329,12 +329,12 @@ favorites_toggle_cb (GtkToggleAction *action, BrowserPerspective *bpers)
 
 static const GtkToggleActionEntry ui_toggle_actions [] =
 {
-        { "DataManagerFavoritesShow", NULL, N_("_Show favorites"), "F9", N_("Show or hide favorites"), G_CALLBACK (favorites_toggle_cb), FALSE}
+        { "DataManagerFavoritesShow", NULL, N_("_Show Favorites"), "F9", N_("Show or hide favorites"), G_CALLBACK (favorites_toggle_cb), FALSE}
 };
 
 static GtkActionEntry ui_actions[] = {
         { "DataManagerMenu", NULL, N_("_Manager"), NULL, N_("Manager"), NULL },
-        { "NewDataManager", GTK_STOCK_NEW, N_("_New data manager"), "<control>T", N_("New data manager"),
+        { "NewDataManager", GTK_STOCK_NEW, N_("_New Data Manager"), "<control>T", N_("New data manager"),
           G_CALLBACK (manager_new_cb)},
 };
 
