@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,14 +38,14 @@ typedef struct _DataManagerPerspectivePriv DataManagerPerspectivePriv;
 /* struct for the object's data */
 struct _DataManagerPerspective
 {
-	GtkVBox                     object;
+	GtkBox                     object;
 	DataManagerPerspectivePriv *priv;
 };
 
 /* struct for the object's class */
 struct _DataManagerPerspectiveClass
 {
-	GtkVBoxClass                parent_class;
+	GtkBoxClass                parent_class;
 };
 
 /**
