@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +24,8 @@
 #include "data-source.h"
 #include <libgda/libgda.h>
 #include "../support.h"
+#include "../../tool-utils.h"
+#include <libgda/gda-debug-macros.h>
 
 #ifdef HAVE_GTKSOURCEVIEW
 #ifdef GTK_DISABLE_SINGLE_INCLUDES
@@ -167,8 +170,8 @@ signal_editor_changed (XmlSpecEditor *sped)
 
 	if (!doc) {
 		TO_IMPLEMENT;
-		g_set_error (&lerror, 0, 0,
-			     _("Error parsing XML specifications"));
+		g_set_error (&lerror, GDA_TOOLS_ERROR, GDA_TOOLS_INTERNAL_COMMAND_ERROR,
+			     "%s", _("Error parsing XML specifications"));
 		goto out;
 	}
 
@@ -181,7 +184,7 @@ signal_editor_changed (XmlSpecEditor *sped)
 	}
 
 	if (strcmp ((gchar*) node->name, "data")) {
-		g_set_error (&lerror, 0, 0,
+		g_set_error (&lerror, GDA_TOOLS_ERROR, GDA_TOOLS_INTERNAL_COMMAND_ERROR,
 			     _("Expecting <%s> root node"), "data");
 		xmlFreeDoc (doc);
 		goto out;
