@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +24,7 @@
 #include "entry-properties.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-page.h"
 #include "../browser-stock-icons.h"
 #include "../browser-window.h"
@@ -32,6 +33,7 @@
 #include "mgr-ldap-entries.h"
 #include <libgda-ui/gdaui-tree-store.h>
 #include "ldap-browser-perspective.h"
+#include <libgda/gda-debug-macros.h>
 
 typedef struct {
 	gchar *dn;
@@ -62,26 +64,13 @@ struct _LdapEntriesPagePrivate {
 static void ldap_entries_page_class_init (LdapEntriesPageClass *klass);
 static void ldap_entries_page_init       (LdapEntriesPage *ebrowser, LdapEntriesPageClass *klass);
 static void ldap_entries_page_dispose   (GObject *object);
-static void ldap_entries_page_set_property (GObject *object,
-					  guint param_id,
-					  const GValue *value,
-					  GParamSpec *pspec);
-static void ldap_entries_page_get_property (GObject *object,
-					  guint param_id,
-					  GValue *value,
-					  GParamSpec *pspec);
+
 /* BrowserPage interface */
 static void                 ldap_entries_page_page_init (BrowserPageIface *iface);
 static GtkActionGroup      *ldap_entries_page_page_get_actions_group (BrowserPage *page);
 static const gchar         *ldap_entries_page_page_get_actions_ui (BrowserPage *page);
 static GtkWidget           *ldap_entries_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button);
 
-
-/* properties */
-enum {
-        PROP_0,
-};
-
 static GObjectClass *parent_class = NULL;
 
 
@@ -96,10 +85,6 @@ ldap_entries_page_class_init (LdapEntriesPageClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	/* Properties */
-        object_class->set_property = ldap_entries_page_set_property;
-        object_class->get_property = ldap_entries_page_get_property;
-
 	object_class->dispose = ldap_entries_page_dispose;
 }
 
@@ -180,36 +165,6 @@ ldap_entries_page_get_type (void)
 	return type;
 }
 
-static void
-ldap_entries_page_set_property (GObject *object,
-			      guint param_id,
-			      G_GNUC_UNUSED const GValue *value,
-			      GParamSpec *pspec)
-{
-	LdapEntriesPage *ebrowser;
-	ebrowser = LDAP_ENTRIES_PAGE (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
-static void
-ldap_entries_page_get_property (GObject *object,
-			      guint param_id,
-			      G_GNUC_UNUSED GValue *value,
-			      GParamSpec *pspec)
-{
-	LdapEntriesPage *ebrowser;
-	ebrowser = LDAP_ENTRIES_PAGE (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
 static gchar *
 ldap_entries_page_to_selection (G_GNUC_UNUSED LdapEntriesPage *ebrowser)
 {
@@ -366,7 +321,7 @@ ldap_entries_page_new (BrowserConnection *bcnc, const gchar *dn)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("LDAP entries browser"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (ebrowser), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
@@ -471,13 +426,13 @@ action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, LdapEntriesPage *ebrowser
 	hierarchy_view_get_current_dn (HIERARCHY_VIEW (ebrowser->priv->entries_view), &cn);
         memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
         fav.id = -1;
-        fav.type = TOOLS_FAVORITES_LDAP_DN;
+        fav.type = GDA_TOOLS_FAVORITES_LDAP_DN;
         fav.name = ldap_entries_page_to_selection (ebrowser);
         fav.descr = (gchar*) cn;
         fav.contents = ldap_entries_page_to_selection (ebrowser);
 
         bfav = browser_connection_get_favorites (ebrowser->priv->bcnc);
-        if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, G_MAXINT, &error)) {
+        if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, G_MAXINT, &error)) {
                 browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) ebrowser),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -558,9 +513,9 @@ static GtkActionEntry ui_actions[] = {
 	{ "LDAP", NULL, N_("_LDAP"), NULL, N_("LDAP"), NULL },
 	{ "AddToFav", STOCK_ADD_BOOKMARK, N_("Add to _Favorites"), NULL, N_("Add entry to favorites"),
 	  G_CALLBACK (action_add_to_fav_cb)},
-	{ "DnBack", GTK_STOCK_GO_BACK, N_("Previous entry"), NULL, N_("Move back to previous LDAP entry"),
+	{ "DnBack", GTK_STOCK_GO_BACK, N_("Previous Entry"), NULL, N_("Move back to previous LDAP entry"),
 	  G_CALLBACK (action_dn_back_cb)},
-	{ "DnForward", GTK_STOCK_GO_FORWARD, N_("Next entry"), NULL, N_("Move to next LDAP entry"),
+	{ "DnForward", GTK_STOCK_GO_FORWARD, N_("Next Entry"), NULL, N_("Move to next LDAP entry"),
 	  G_CALLBACK (action_dn_forward_cb)},
 };
 static const gchar *ui_actions_browser =
