@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -20,7 +21,7 @@
 #include <string.h>
 #include "ldap-search-page.h"
 #include "filter-editor.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-page.h"
 #include "../browser-window.h"
 #include "../browser-connection.h"
@@ -28,6 +29,7 @@
 #include <common/ui-formgrid.h>
 #include "../browser-stock-icons.h"
 #include "vtable-dialog.h"
+#include <libgda/gda-debug-macros.h>
 
 typedef struct {
 	gchar              *base_dn;
@@ -284,7 +286,7 @@ ldap_search_page_new (BrowserConnection *bcnc, const gchar *base_dn)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("LDAP search page"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (epage), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
@@ -461,7 +463,7 @@ action_class_forward_cb (G_GNUC_UNUSED GtkAction *action, LdapSearchPage *epage)
 */
 static GtkActionEntry ui_actions[] = {
 	{ "LDAP", NULL, N_("_LDAP"), NULL, N_("LDAP"), NULL },
-	{ "DefineAsTable", BROWSER_STOCK_TABLE_ADD, N_("Define as table"), NULL, N_("Define search as a virtual table"),
+	{ "DefineAsTable", BROWSER_STOCK_TABLE_ADD, N_("Define as Table"), NULL, N_("Define search as a virtual table"),
 	  G_CALLBACK (action_define_as_table_cb)},
 	/*
 	{ "DnBack", GTK_STOCK_GO_BACK, N_("Previous class"), NULL, N_("Move back to previous LDAP class"),
